@@ -39,7 +39,7 @@ def get_static_settings():
         if AWS_STATIC_S3_SECURE:
             AWS_STATIC_S3_SECURE = literal_eval(AWS_STATIC_S3_SECURE.capitalize())
         STATICFILES_STORAGE = 'django_setup.aws_s3.backends.StaticS3Storage'
-        STATIC_URL = AWS_STATIC_S3_DOMAIN
+        STATIC_URL = '%s/' % AWS_STATIC_S3_DOMAIN
     else:
         # URL prefix for static files.
         # For local development, we use the default
@@ -60,7 +60,7 @@ def get_media_settings():
         if AWS_MEDIA_S3_SECURE:
             AWS_MEDIA_S3_SECURE = literal_eval(AWS_MEDIA_S3_SECURE.capitalize())
         DEFAULT_FILE_STORAGE = 'django_setup.aws_s3.backends.MediaS3Storage'
-        MEDIA_URL = AWS_MEDIA_S3_DOMAIN
+        MEDIA_URL = '%s/' % AWS_MEDIA_S3_DOMAIN
         MEDIA_ROOT = ''
     else:
         # URL prefix for static files.
